%%
%% This is file `pfuef.cls', pdflatex class file to generate slides
%% without any post processing.
%% Copyright (C) 2004-2012  Reinhard Furrer
%%                          reinhard.furrer@math.uzh.ch
%% 
%% This program is free software; you can redistribute it and/or
%% modify it under the terms of the GNU General Public License
%% as published by the Free Software Foundation; either version 2
%% of the License, or (at your option) any later version.
%% 
%% This program is distributed in the hope that it will be useful,
%% but WITHOUT ANY WARRANTY; without even the implied warranty of
%% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%% GNU General Public License for more details.
%% 
%% You should have received a copy of the GNU General Public License
%% along with this program; if not, write to the Free Software
%% Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307,
%% USA.
%% 
\NeedsTeXFormat{LaTeX2e}[1995/12/01]
\ProvidesClass{pfuef}
              [2012/04/18 v2.4.UZH pfuef]

\RequirePackage[usenames,dvipsnames]{color}
\RequirePackage[pdftex]{graphicx}
\RequirePackage{calc}

% loaded but not essental for pfuef:
\usepackage{amssymb,amsmath}
\usepackage[colorlinks=true,%
            plainpages=false,pageanchor=false,pdfpagelabels=false,%
            pdfcreator={pdflatex with pfuef}]{hyperref}

\@ifundefined{pdfoutput}
  {\PackageError{pfuef}
              {You're probably not using pdfLaTeX}
              {Use `pdflatex' instead of `latex'}}

\global\newif\ifbgcolor\bgcolorfalse
\newif\ifprint\printfalse
\newif\ifppremarks\ppremarksfalse
\global\newif\ifbgimage\bgimagefalse
\newif\ifgridin\gridinfalse
\newif\ifgridcm\gridcmfalse


\definecolor{bgblue}{rgb}{0.1882353,0.3607843,0.7529412}


\DeclareOption{bgimage}{
  \def\coldot{\includegraphics[height=10pt]{\@figuredir grayontransdot.pdf}}
  \bgimagetrue
}


\DeclareOption{ppremarks}{
  \ppremarkstrue
}

\DeclareOption{print}{
  \def\coldot{\includegraphics[height=10pt]{\@figuredir blueonwhitedot.png}}
  \bgimagefalse
  \bgcolorfalse
  \def\pause{\par}
  \printtrue
}
\DeclareOption{gridin}{
  \gridintrue
  \gridcmfalse
}
\DeclareOption{gridcm}{
  \gridinfalse
  \gridcmtrue
}

\DeclareOption{bgcolor}{
  \def\coldot{\includegraphics[height=10pt]{\@figuredir grayontransdot.pdf}}
  \def\pause{\@pause}
  \bgcolortrue
  \typeout{^^J       Thanks for using pfuef v2.4.uzh}
  \typeout{ Send comments to reinhard.furrer@math.uzh.ch}
}

\DeclareOption{43ratio}
   {\setlength\paperheight {210mm}%
    \setlength\paperwidth  {280mm}}
\DeclareOption{a4paper}
   {\setlength\paperheight {210mm}%
    \setlength\paperwidth  {297mm}}
\DeclareOption{a5paper}
   {\setlength\paperheight {148mm}%
    \setlength\paperwidth  {210mm}}
\DeclareOption{b5paper}
   {\setlength\paperheight {176mm}%
    \setlength\paperwidth  {250mm}}
\DeclareOption{letterpaper}
   {\setlength\paperheight {8.5in}%
    \setlength\paperwidth  {11in}}
\DeclareOption{legalpaper}
   {\setlength\paperheight {8.5in}%
    \setlength\paperwidth  {14in}}
\DeclareOption{executivepaper}
   {\setlength\paperheight {7.25in}%
    \setlength\paperwidth  {10.5in}}


\ExecuteOptions{43ratio,bgcolor}
\ProcessOptions

% set dimensions
% Nothing to change here:
\headheight 0pt
\headsep 0mm
\oddsidemargin 0 mm
\evensidemargin 0 mm
\topmargin 0 mm

% probably nothing to change here
\baselineskip 14pt
\parindent 0mm

% global skips  
%\parskip 30pt

\newdimen\topsep  % all others are defined

\setlength{\topsep}{10pt}
\setlength{\parsep}{5pt}
\setlength{\itemsep}{10pt}


% can be set... just see below
\newdimen\hfleftmargin
\newdimen\hfrightmargin
\newdimen\srightmargin
\newdimen\stopmargin
\newdimen\sbottommargin
\newdimen\hfwidth
\newdimen\hftitlemargin

% header and footer stuff
\newdimen\footerimagewidth
\footerimagewidth 12.2cm
\newdimen\headerimageheight
\headerimageheight .05in
\newdimen\footerimageheight
\footerimageheight .7in

\newcommand{\settextmargins}[5]{%
  \setlength{\voffset}{#1-1in}
  \setlength{\hoffset}{#2-1in}
  \setlength{\srightmargin}{#3}
  \setlength{\stopmargin}{#4+.1in}
  \setlength{\sbottommargin}{#5}
% resulting lengths  
  \setlength{\textwidth}{\paperwidth-\hoffset-1in-\srightmargin}  
  \setlength{\textheight}{\paperheight-\voffset-1in-\sbottommargin}
}  

\newcommand{\sethfmargins}[5]{%
  \setlength{\hfleftmargin}{\hoffset+1in-#1}  
  \setlength{\hfrightmargin}{#2}
  \setlength{\headerimageheight}{#3}
  \setlength{\footerimageheight}{#4}
  \setlength{\footerimagewidth}{#5}
% resulting lengths  
  \setlength{\hfwidth}{\paperwidth-\hoffset-\hfrightmargin+\hfleftmargin-1in}  
  \setlength{\textwidth}{\paperwidth-\hoffset-1in-\srightmargin}  
  \setlength{\textheight}{\paperheight-\voffset-1in-\srightmargin}
  \setlength{\hftitlemargin}{\hfleftmargin}}


% end set dimensions


% input from slides.cls
\def\rmdefault{lcmss}        % no roman
\def\sfdefault{lcmss}
\def\ttdefault{lcmtt}
\def\itdefault{sl}
\def\sldefault{sl}
\def\bfdefault{bx}
\def\ifourteenpt{13.82}
\def\iseventeenpt{16.59}
\def\itwentypt{19.907}
\def\itwentyfourpt{23.89}
\def\itwentyninept{28.66}
\def\ithirtyfourpt{34.4}
\def\ifortyonept{41.28}
\def\@setfontsize@parms#1#2#3#4#5#6#7#8{%
   \lineskip #1\relax%
   \parskip #2\relax
   \abovedisplayskip #3\relax
   \belowdisplayskip #4\relax
   \abovedisplayshortskip #5\relax
   \belowdisplayshortskip #6\relax
  \setbox\strutbox=\hbox{\vrule \@height#7\p@\@depth#8\p@\@width\z@}%
  \baselineskip\baselinestretch\baselineskip
  \normalbaselineskip\baselineskip}
\DeclareMathSizes{13.82}{13.82}{10}{7}
\DeclareMathSizes{16.59}{16.59}{12}{7}
\DeclareMathSizes{19.907}{19.907}{16.59}{13.82}
\DeclareMathSizes{23.89}{23.89}{19.907}{16.59}
\DeclareMathSizes{28.66}{28.66}{23.89}{19.907}
\DeclareMathSizes{34.4}{34.4}{28.66}{23.89}
\DeclareMathSizes{41.28}{41.28}{34.4}{28.66}
\def\normalsize{%
      \@setfontsize\normalsize\itwentypt{28\p@}%
      \@setfontsize@parms
            {2pt}%
            {20\p@}%  
            {15\p@}%
            {10\p@}%
            {10\p@}
            \abovedisplayshortskip
            {17}{7}}
\normalsize
\def\small{\@setfontsize\small\iseventeenpt{19\p@}%
           \@setfontsize@parms
            {2\p@}%
            {15\p@}%
            {12\p@}%
            {9\p@}%
            {6\p@}%
            \abovedisplayshortskip
            {13.5}{5.6}}
\let\footnotesize=\small
\let\scriptsize=\small
\def\tiny{\@setfontsize\tiny\ifourteenpt{16\p@}%
          \@setfontsize@parms
            {2pt}%
            {14\p@}%
            {11\p@}%
            \abovedisplayskip
            {8\p@}%
            {\z@}%
            {10}{4}}
\def\large{\@setfontsize\large\itwentyfourpt{42\p@}%
           \@setfontsize@parms
            {2\p@}%
            {20\p@}%
            {20\p@}%
            \abovedisplayskip
            {10\p@}%
            \abovedisplayshortskip
            {20}{8.5}}

\def\Large{\@setfontsize\Large\itwentyninept{48\p@}%
           \@setfontsize@parms
            {2\p@}%
            {24\p@}%
            {24\p@}%
            \abovedisplayskip
            {12\p@}%
            \abovedisplayshortskip
            {27}{11}}

\def\LARGE{\@setfontsize\LARGE\ithirtyfourpt{52\p@}%
           \@setfontsize@parms
            {2\p@}%
            {24\p@}%
            {24\p@}%
            \abovedisplayskip
            {12\p@}%
            \abovedisplayshortskip
            {27}{11}}

\def\huge{\@setfontsize\huge\ifortyonept{60\p@}%
           \@setfontsize@parms
            {2\p@}%
            {24\p@}%
            {24\p@}%
            \abovedisplayskip
            {12\p@}%
            \abovedisplayshortskip
            {27}{11}}

\let\Huge\huge
\renewcommand\baselinestretch{}

\@lowpenalty   51
\@medpenalty  151
\@highpenalty 301




\@settopoint\topmargin
\DeclareMathVersion{invisible}
\SetSymbolFont{operators}{normal}
                 {OT1}{lcmss}{m}{n}
\SetSymbolFont{letters}{normal}
                 {OML}{lcmm}{m}{it}
\SetSymbolFont{symbols}{normal}
                 {OMS}{lcmsy}{m}{n}
\SetSymbolFont{largesymbols}{normal}
                 {OMX}{lcmex}{m}{n}
\SetSymbolFont{operators}{invisible}
                 {OT1}{lcmss}{m}{In}
\SetSymbolFont{letters}{invisible}
                 {OML}{lcmm}{m}{Iit}
\SetSymbolFont{symbols}{invisible}
                 {OMS}{lcmsy}{m}{In}
\SetSymbolFont{largesymbols}{invisible}
                  {OMX}{lcmex}{m}{In}

\def\@mainsize{\visible\tiny}



\setlength\leftmargini   {38\p@}
\setlength\leftmarginii  {30\p@}
\setlength\leftmarginiii {20\p@}
\def\@listi{\leftmargin\leftmargini}

\def\@listii{\leftmargin\leftmarginii
             \labelwidth\leftmarginii
             \advance\labelwidth-\labelsep}
\def\@listiii{\leftmargin\leftmarginiii
              \labelwidth\leftmarginiii
              \advance\labelwidth-\labelsep}
\leftmargin\leftmargini
\labelwidth\leftmargini\advance\labelwidth-\labelsep

\newenvironment{description}{\list{}{\labelwidth\z@
                                     \itemindent-\leftmargin
                                     \let\makelabel\descriptionlabel}}
                            {\endlist}
\newcommand*{\descriptionlabel}[1]{\hspace\labelsep
                                \normalfont\bfseries #1}

\renewcommand\theenumi{\@arabic\c@enumi}
\renewcommand\theenumii{\@alph\c@enumii}
\renewcommand\theenumiii{\@roman\c@enumiii}
\newcommand\labelenumi{\theenumi.}
\newcommand\labelenumii{(\theenumii)}
\newcommand\labelenumiii{\theenumiii.}
\renewcommand\p@enumii{\theenumi}
\renewcommand\p@enumiii{\theenumi(\theenumii)}
\newcommand\labelitemi{{\bc$\m@th\bullet$}}
\newcommand\labelitemii{\normalfont\bfseries \textendash}
\newcommand\labelitemiii{$\m@th\ast$}
\setlength\arraycolsep{8\p@}
\setlength\tabcolsep{10\p@}
\setlength\arrayrulewidth{.6\p@}
\setlength\doublerulesep{3\p@}
\labelsep 10pt
\setlength\tabbingsep{\labelsep}
\skip\@mpfootins = \skip\footins
\setlength\fboxsep{0\p@}
\setlength\fboxrule{.6\p@}
\def\theequation{\@arabic\c@equation}
\DeclareOldFontCommand{\rm}{\normalfont\rmfamily}{\mathrm}
\DeclareOldFontCommand{\sf}{\normalfont\sffamily}{\mathsf}
\DeclareOldFontCommand{\tt}{\normalfont\ttfamily}{\mathtt}
\DeclareOldFontCommand{\bf}{\normalfont\bfseries}{\mathbf}
\DeclareOldFontCommand{\it}{\normalfont\itshape}{\mathit}
\DeclareOldFontCommand{\sl}{\normalfont\slshape}{\relax}
\DeclareOldFontCommand{\sc}{\normalfont\scshape}{\relax}
\DeclareRobustCommand*{\cal}{\@fontswitch{\relax}{\mathcal}}
\DeclareRobustCommand*{\mit}{\@fontswitch{\relax}{\mathnormal}}
% end input from slides.cls

%% inspired from (an old) Version 1.1 of pause.sty (25 May 99) 
%% written by Klaus Guntermann guntermann@iti.informatik.tu-darmstadt.de
\newbox\p@uses@vebox
\newtoks\p@uses@veoutput

\def\@pause{\p@uses@veoutput=\output % make backup copy of output routine
  \output={\global\setbox\p@uses@vebox=\box255}% copy current
      % contents only, when triggered
  \vfill\eject % trigger now
  \output=\p@uses@veoutput % restore output routine
  \unvcopy\p@uses@vebox % insert contents
  \eject % now really show the output
  \unvbox\p@uses@vebox\vskip-\lastskip % and insert again for next turn
}


% unnumbered list (originally from an old jasa.sty)
\def\ul{\bgroup\smallskip
\parindent-8pt
\parskip 10pt
\leftskip=26pt}
\def\endul{\vskip1sp\smallskip\egroup}

% definition of variables and lengths
\newcounter{slideno}
\setcounter{slideno}{1}

\newcount\ppnr  % nr of lines for ppremarks
\newcount\dotnr % nr of dots

\ifbgcolor\ppremarksfalse\fi
\ifprint\bgimagefalse\fi

\newsavebox{\wppr}% contains the box for ppremarks
 
\newif\ifqtmp\qtmptrue      % false if page does not need to be
                            % processed in print mode
\newif\ifsdpage\sdpagefalse % true if we are on slide 2 or higher

\def\myitem{\hspace*{4pt}\raisebox{1mm}[0pt][0pt]{\coldot\hspace*{4pt}}}




% main definition, all variants call @@slide
\def\titleslide{\let\@@backgroundimage\@titlebackgroundimage\def\@nummi{}\def\@@nummi{}\@@slide<>{}\let\@@backgroundimage\@backgroundimage%the following is changed with respect to the classical pfuef, i.e. UZH specific!
\footerimage{uzh_logo_e_pos_klein.png}\sethfmargins{0in}{0in}{0in}{75px}{184px}\bgimagefalse\vspace*{-2cm}\color{yellow}}


\def\slide{\@ifnextchar *{\def\@nummi{}\@slide}%
{\def\@@nummi{\slidenumber}\def\@nummi{\addtocounter{slideno}{1}}\@slide*}}
\def\@slide*{\@ifnextchar <{\@@slide}{\@@slide<>}}


% main function composes the slide background
\long\def\@@slide<#1>#2{{}\normalsize\qtmptrue\if#1* \ifprint\par\vspace*{-5\paperheight} \qtmpfalse \fi \fi%
\ifqtmp\ifsdpage\ifppremarks\writeppremarks\fi\fi\newpage
\ifbgimage{\raisebox{-\paperheight+\voffset+1in+10pt}[0pt][0pt]{\hspace*{-1in}\hspace*{-\hoffset}\rlap{\includegraphics[height=\paperheight,width=\paperwidth]{\@@backgroundimage}}}\hspace*{1in}\hspace*{\hoffset}%
}\fi% background image is placed
\sbox{\wppr}{\vbox{\tc#1}}% place the ppremarks in a box, which will be processed later
\raisebox{\stopmargin+\headerimageheight-.5in}[0pt][0pt]{\placeheader}% place header and advance some space 
\raisebox{\stopmargin}[0pt][0pt]{\writetitle{#2}}% write the title is fixed
\raisebox{-\paperheight+\voffset+1in+\sbottommargin+3pt}[0pt][0pt]{\placefooter}% place footer and backup
\hspace*{\hftitlemargin}\vspace*{-35pt}%\par%
\ifgridcm\helpinggridcm\fi\ifgridin\helpinggridin\vspace*{0mm}\fi\par% If necessary place grids
\@texfs% define default textsize
\fi\sdpagetrue\tc}% from now on consider ppremarks


\def\placeheader{\hspace*{-\hfleftmargin}%
\rlap{\begin{minipage}[t]{\textwidth}\@header\end{minipage}}}
\def\placefooter{%
\rlap{\begin{minipage}[b]{\textwidth}\makebox[0pt][l]{\@footer}{\@nummi}\rlap{\@@nummi}\end{minipage}}}
% rlap to restart over, raisebox to be height independent and minipage
% for paragraph construction. raisebox is not needed in the header



\newcommand{\writetitle}[1]{%
  \rlap{\hspace*{\hftitlemargin}\@htc\@titfs\bfseries{\vbox{#1}}}\par
}


\long\def\maintitle#1#2#3{\vspace*{99mm}{\large%
\hspace*{-16mm}#2\\[7mm]
\hspace*{-16mm}#3\\[-20mm]}
{\hspace*{23.8cm}\color{gray}{\tiny NZZ.ch}}\vspace*{-130mm}
\begin{center}\huge\bf #1\end{center}}

\def\slidenumber{%
\raisebox{6mm}[0mm][0mm]{%
\hspace*{\hfleftmargin}\hspace*{\textwidth}\small\llap{\@ftc\theslideno}}}

%%%% commands for headers and footers
\def\header#1{%
\def\@header{\typeout{pfuef Warning: header type not defined}}%
\ifx#10\def\@header{}\fi%
\ifx#11\def\@header{%
  \vspace*{-7.25mm}\rlap{\includegraphics[height=\headerimageheight,width=\hfwidth]{\@headerimage}}}\fi%
\ifx#12\def\@header{%
  \vspace*{-23mm}\vbox{\coldot\\[-5mm]\coldot\\[-5mm]\coldot\\[2mm]%
  \rlap{\includegraphics[height=\headerimageheight,width=\hfwidth]{\@headerimage}}}%
}\fi}

\def\footer#1{%
\def\@footer{\typeout{pfuef Warning: footer type not defined}}%
\ifx#10\def\@footer{}\fi%
%
\ifx#11\def\@footer{%
 \rlap{\includegraphics[height=\footerimageheight,width=\footerimagewidth]{\@footerimage}}%
 \raisebox{6mm}[0mm][0mm]{\hspace*{\hftitlemargin}\@ftc\@footertext}}\fi%
%
\ifx#12\def\@footer{%
  \rlap{\includegraphics[height=\footerimageheight,width=\footerimagewidth]{\@footerimage}%
  \raisebox{.8\footerimageheight}[0mm][0mm]{%
  \hskip-2.7mm\dotnr=11
  \loop \ifnum\dotnr>0\hskip8.6mm\coldot\advance \dotnr by -1 \repeat}}%
  \raisebox{6mm}[0mm][0mm]{\hspace*{\hftitlemargin}\@ftc\@footertext}}\fi%
\ifx#13\def\@footer{%
 \raisebox{6mm}[0mm][0mm]{\hspace*{\hftitlemargin}\@ftc\@footertext}}\fi}%
%
%%%% end headers and footers


%%%% commands for ppremarks
\newcommand{\writeppremarks}{\newpage
\begin{minipage}{\textwidth}%
\tc\usebox{\wppr}
\end{minipage}\newpage}

\newcommand{\ppline}{ \rule{\textwidth}{.2mm}\\}
\def\pplines#1{\ppnr=#1
\loop \ifnum\ppnr>0 \ppline \advance \ppnr by -1 \repeat}

\AtEndDocument{\ifppremarks\writeppremarks\fi}
%%%% end ppremarks

\def\@nummi{}\def\@@nummi{}

\def\footertext#1{\def\@footertext{#1}}
\def\headerimage#1{\def\@headerimage{\@figuredir#1}}
\def\footerimage#1{\def\@footerimage{\@figuredir#1}}
\def\backgroundimage#1{\def\@backgroundimage{\@figuredir#1}\let\@@backgroundimage\@backgroundimage}
\def\titlebackgroundimage#1{\def\@titlebackgroundimage{\@figuredir#1}}
\def\figuredir#1{\def\@figuredir{#1}}
%\def\@@backgroundimage{\@backgroundimage}

\def\titlefontsize#1{\def\@titfs{#1}}
\def\textfontsize#1{\def\@texfs{#1}}

\newcommand{\setcolortc}[2][black]{\ifprint\def\tc{\color{#1}}\else\def\tc{\color{#2}}\fi}
\newcommand{\setcolorbc}[2][black]{\ifprint\def\bc{\color{#1}}\else\def\bc{\color{#2}}\fi}
\newcommand{\setcolorec}[2][black]{\ifprint\def\ec{\color{#1}}\else\def\ec{\color{#2}}\fi}

\newcommand{\slidebackgroundcolor}[2][white]{\ifprint\pagecolor{#1}\else\pagecolor{#2}\fi}

\newcommand{\footertextcolor}[2][gray80]{\ifprint\def\@ftc{\color{#1}}\else\def\@ftc{\color{#2}}\fi}
\newcommand{\headertextcolor}[2][gray60]{\ifprint\def\@htc{\color{#1}}\else\def\@htc{\color{#2}}\fi}

\newcommand{\shadow}[1]{\hbox{\rlap{\textcolor{black}{\raisebox{1pt}[0pt]{#1}}}%
    \textcolor{white}{\hspace*{2pt}{#1}}}}



\newcommand{\helpinggridin}{%
\setlength{\unitlength}{1in}%
%\linethickness{1.mm} 
{\tiny%
\begin{picture}(0,0)(0,-.15)
  \color{gray60}
  \thinlines
  \multiput(.5, 0)(1,0){10}{\line(0, -1){5.5}}
  \multiput(0, -.5)(0, -1){6}{\line(1, 0){9.5}}
  \color{gray80}
  \thicklines
  \multiput(0, 0)(1, 0){10}{\line(0, -1){5.5}}
  \multiput(0, 0)(0, -1){6}{\line(1, 0){9.5}}
  \put(0.05, -0.25){0/0}
  \put(0.05, -1.25){0/1}
  \put(0.01, -2.25){0/2}
  \put(0.05, -3.25){0/3}
  \put(0.05, -4.25){0/4}
  \put(0.05, -5.25){0/5}
  \put(1.02, -0.25){1/0}
  \put(2.02, -0.25){2/0}
  \put(3.02, -0.25){3/0}
  \put(4.02, -0.25){4/0}
  \put(5.02, -0.25){5/0}
  \put(6.02, -0.25){6/0}
  \put(7.02, -0.25){7/0}
  \put(8.02, -0.25){8/0}
\end{picture}}}
\newcommand{\helpinggridcm}{%
\setlength{\unitlength}{1cm}%
\begin{picture}(0,0)(0,-.41)
  \color{gray60}\tiny
%  \linethickness{0.05mm}
  \thinlines
  \multiput(1, 0)(2,0){12}{\line(0, -1){14}}
  \multiput(0, -1)(0, -2){7}{\line(1, 0){23}}
  \color{gray80}
  \thicklines
  \multiput(0, 0)(2, 0){12}{\line(0, -1){14}}
  \multiput(0, 0)(0, -2){8}{\line(1, 0){23}}
  \put(0.05, -0.62){0}
  \put(0.05, -2.62){2}
  \put(0.05, -4.62){4}
  \put(0.05, -6.62){6}
  \put(0.05, -8.62){8}
  \put(0.05, -10.62){10}
  \put(0.05, -12.62){12}
  \put(2.05, -0.62){2}
  \put(4.05, -0.62){4}
  \put(6.05, -0.62){6}
  \put(8.05, -0.62){8}
  \put(10.05, -0.62){10}
  \put(12.05, -0.62){12}
  \put(14.05, -0.62){14}
  \put(16.05, -0.62){16}
  \put(18.05, -0.62){18}
  \put(20.05, -0.62){20}
\end{picture}}

\newcommand{\arrow}[5][arrow]{\raisebox{0pt}[0pt][0pt]{\rlap{\vbox{\hspace*{#2}\vspace*{-#3}\includegraphics[angle=#4,scale=#5]{\@figuredir #1}}}}}
\newcommand{\placeobject}[3]{\raisebox{0pt}[0pt][0pt]{\rlap{\vbox{\hspace*{#1}\vspace*{-#2}#3}}}}
\newcommand{\source}[1]{{\tiny\color{gray}Source: #1}}
\newcommand{\placefig}[4][]{%
\ifEmpty{#1}\raisebox{#2}[0pt][0pt]{\includegraphics[#3]{#4}}\else%
\raisebox{#2}[0pt][0pt]{\vbox{\includegraphics[#3]{#4}\\[-4mm]\source{#1}}}\fi}
% taken from
% http://www.golatex.de/newcommand-und-optionaler-parameter-t2549.html
\def\ifEmpty#1{\def\@temp{#1}\ifx\@temp\@empty} 


% Standardization of the parameters, first common stuff, 
%   then two cases: fields option or not...
\DeclareGraphicsExtensions{.pdf,.png,.jpg}
\figuredir{./p5figures/}
\InputIfFileExists{\@figuredir rgb.tex}{
  \typeout{Loading color table:}}{
  \typeout{Color table ain't available.}

  \definecolor{gray30}{rgb}{0.3,0.3,0.3}
  \definecolor{gray50}{rgb}{0.5,0.5,0.5}
  \definecolor{gray60}{rgb}{0.6,0.6,0.6}
  \definecolor{gray80}{rgb}{0.8,0.8,0.8}
  \definecolor{DarkBlue}{rgb}{0,0,0.5451}
  \definecolor{LightSkyBlue}{rgb}{0.52941,0.80784,0.98039}
  \definecolor{khaki}{rgb}{0.94118,0.90196,0.54902}
  \definecolor{myblue}{rgb}{0.2549020,0.3372549,0.5843137}
  \definecolor{DarkRed}{rgb}{0.5451,0,0}
  \definecolor{green4}{rgb}{0,0.5451,0}

}
\InputIfFileExists{\@figuredir standardmacros.sty}{
  \typeout{Loading standard math macros:}}{
  \typeout{Standard math macros are not available.}
}

\renewcommand\labelitemi{{\raisebox{1.2px}{\mathsurround=5pt\textcolor{DarkRed}{$\blacktriangleright$}}}}


\usepackage{amssymb,amsmath}
\providecommand{\thepage}{}

\bgimagetrue

\titlebackgroundimage{uni_zuerich.jpg}
\footerimage{uzh_logo_title.png}
\slidebackgroundcolor{white}


\setcolortc[black]{black}
\setcolorbc[black]{black}
\setcolorec[DarkBlue]{DarkBlue}
\footertextcolor{gray60}
\headertextcolor{DarkRed}

\footer1
\header0


\footertext{}

\titlefontsize{\LARGE}
\textfontsize{\normalsize}



% margins: top, left right of text, dist to header, dist to bottom
\settextmargins{1.55in}{.85in}{.5in}{.65in}{0in}
% header and footer images...
\sethfmargins{0in}{0in}{0in}{108px}{266px}


\endinput

